require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xdscwebservice',
  dscmeta_resource_friendly_name: 'xDSCWebService',
  dscmeta_resource_name: 'DSC_xDSCWebService',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xPSDesiredStateConfiguration',
  dscmeta_module_version: '9.2.1',
  docs: 'The DSC xDSCWebService resource type.
         Automatically generated from version 9.2.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_modulepath: {
      type: 'Optional[String]',
      desc: 'The location on the disk where the Modules are stored.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_registrationkeypath: {
      type: 'Optional[String]',
      desc: 'The location on the disk where the RegistrationKeys file is stored.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sqlprovider: {
      type: 'Optional[Boolean]',
      desc: 'Enable DSC Pull Server to use SQL server as the backend database.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_port: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'The port number of the DSC Pull Server IIS Endpoint.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_applicationpoolname: {
      type: 'Optional[String]',
      desc: "The IIS Application Pool to use for the Pull Server. If not specified a pool with name 'PSWS' will be created.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_configurefirewall: {
      type: 'Optional[Boolean]',
      desc: 'Enable incoming firewall exceptions for the configured DSC Pull Server port. Defaults to true.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Variant[String[1], Sensitive[String[1]]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_configurationpath: {
      type: 'Optional[String]',
      desc: 'The location on the disk where the Configuration is stored.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_certificatetemplatename: {
      type: 'Optional[String]',
      desc: 'The certificate Template Name of the Certificate in CERT:\LocalMachine\MY\ for Pull Server.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_dscserverurl: {
      type: 'Optional[String]',
      desc: 'The URL of the DSC Pull Server.',

      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sqlconnectionstring: {
      type: 'Optional[String]',
      desc: 'The connection string to use to connect to the SQL server backend database. Required if SqlProvider is true.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_certificatesubject: {
      type: 'Optional[String]',
      desc: 'The subject of the Certificate in CERT:\LocalMachine\MY\ for Pull Server.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_usesecuritybestpractices: {
      type: 'Boolean',
      desc: 'This property will ensure that the Pull Server is created with the most secure practices.',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_physicalpath: {
      type: 'Optional[String]',
      desc: 'The physical path for the IIS Endpoint on the machine (usually under inetpub).',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_certificatethumbprint: {
      type: 'Optional[String]',
      desc: 'The thumbprint of the Certificate in CERT:\LocalMachine\MY\ for Pull Server.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_state: {
      type: "Optional[Enum['Started', 'started', 'Stopped', 'stopped']]",
      desc: 'Specifies the state of the DSC Web Service.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_disablesecuritybestpractices: {
      type: "Optional[Array[Enum['SecureTLSProtocols', 'securetlsprotocols']]]",
      desc: 'A list of exceptions to the security best practices to apply.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_databasepath: {
      type: 'Optional[String]',
      desc: 'The location on the disk where the database is stored.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Specifies if the DSC Web Service should be installed.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_endpointname: {
      type: 'String',
      desc: 'Prefix of the WCF SVC file.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enable32bitapponwin64: {
      type: 'Optional[Boolean]',
      desc: 'Enable the DSC Pull Server to run in a 32-bit process on a 64-bit operating system.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_acceptselfsignedcertificates: {
      type: 'Optional[Boolean]',
      desc: 'Specifies is self-signed certs will be accepted for client authentication.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
