require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xpsendpoint',
  dscmeta_resource_friendly_name: 'xPSEndpoint',
  dscmeta_resource_name: 'DSC_xPSSessionConfiguration',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xPSDesiredStateConfiguration',
  dscmeta_module_version: '9.2.1',
  docs: 'The DSC xPSEndpoint resource type.
         Automatically generated from version 9.2.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Variant[String[1], Sensitive[String[1]]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_accessmode: {
      type: "Optional[Enum['Local', 'local', 'Remote', 'remote', 'Disabled', 'disabled']]",
      desc: "Enables and disables the session configuration and determines whether it can be used for remote or local sessions on the computer. The default value is 'Remote'.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'Specifies the name of the session configuration.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_securitydescriptorsddl: {
      type: 'Optional[String]',
      desc: 'Specifies the Security Descriptor Definition Language (SDDL) string for the configuration. This string determines the permissions that are required to use the new session configuration. To use a session configuration in a session, users must have at least Execute(Invoke) permission for the configuration.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: "Indicates if the session configuration should exist. The default value is 'Present'.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_startupscript: {
      type: 'Optional[String]',
      desc: 'Specifies the startup script for the configuration. Enter the fully qualified path of a Windows PowerShell script.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_runascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Variant[String[1], Sensitive[String[1]]] }]]',
      desc: 'Specifies the credential for commands of this session configuration. By default, commands run with the permissions of the current user.',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
  },
)
